# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/utilization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/utilization.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\023ApiUtilizationProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15\x61pi/utilization.proto\x12\x0b\x62lueapi.api\"H\n\x0fUtilizationData\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\tchartData\x18\x02 \x03(\x0b\x32\x16.blueapi.api.ChartData\"q\n\tChartData\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x0c\n\x04\x63ost\x18\x03 \x01(\x01\x12\x0e\n\x06profit\x18\x04 \x01(\x01\x12\x13\n\x0butilization\x18\x05 \x01(\x01\x12\x12\n\ncommitment\x18\x06 \x01(\x01\x42X\n\x19\x63loud.alphaus.blueapi.apiB\x13\x41piUtilizationProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_UTILIZATIONDATA = _descriptor.Descriptor(
  name='UtilizationData',
  full_name='blueapi.api.UtilizationData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.UtilizationData.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chartData', full_name='blueapi.api.UtilizationData.chartData', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=110,
)


_CHARTDATA = _descriptor.Descriptor(
  name='ChartData',
  full_name='blueapi.api.ChartData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.ChartData.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='blueapi.api.ChartData.service', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='blueapi.api.ChartData.cost', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profit', full_name='blueapi.api.ChartData.profit', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='utilization', full_name='blueapi.api.ChartData.utilization', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commitment', full_name='blueapi.api.ChartData.commitment', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=225,
)

_UTILIZATIONDATA.fields_by_name['chartData'].message_type = _CHARTDATA
DESCRIPTOR.message_types_by_name['UtilizationData'] = _UTILIZATIONDATA
DESCRIPTOR.message_types_by_name['ChartData'] = _CHARTDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UtilizationData = _reflection.GeneratedProtocolMessageType('UtilizationData', (_message.Message,), {
  'DESCRIPTOR' : _UTILIZATIONDATA,
  '__module__' : 'api.utilization_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.UtilizationData)
  })
_sym_db.RegisterMessage(UtilizationData)

ChartData = _reflection.GeneratedProtocolMessageType('ChartData', (_message.Message,), {
  'DESCRIPTOR' : _CHARTDATA,
  '__module__' : 'api.utilization_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.ChartData)
  })
_sym_db.RegisterMessage(ChartData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
