# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/coverage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/coverage.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\020ApiCoverageProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12\x61pi/coverage.proto\x12\x0b\x62lueapi.api\"J\n\x0bOptionsData\x12\n\n\x02id\x18\x01 \x01(\t\x12/\n\x0coptionsChart\x18\x02 \x03(\x0b\x32\x19.blueapi.api.OptionsChart\"=\n\x0cOptionsChart\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x10\n\x08\x63overage\x18\x02 \x01(\x01\x12\r\n\x05usage\x18\x03 \x01(\x01\"M\n\x0cOndemandData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x31\n\rondemandChart\x18\x02 \x03(\x0b\x32\x1a.blueapi.api.OndemandChart\"l\n\rOndemandChart\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x17\n\x0fnormalizedUsage\x18\x03 \x01(\x01\x12\x14\n\x0condemandCost\x18\x04 \x01(\x01\x12\r\n\x05usage\x18\x05 \x01(\x01\x42U\n\x19\x63loud.alphaus.blueapi.apiB\x10\x41piCoverageProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_OPTIONSDATA = _descriptor.Descriptor(
  name='OptionsData',
  full_name='blueapi.api.OptionsData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.OptionsData.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optionsChart', full_name='blueapi.api.OptionsData.optionsChart', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=109,
)


_OPTIONSCHART = _descriptor.Descriptor(
  name='OptionsChart',
  full_name='blueapi.api.OptionsChart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.OptionsChart.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coverage', full_name='blueapi.api.OptionsChart.coverage', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='blueapi.api.OptionsChart.usage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=172,
)


_ONDEMANDDATA = _descriptor.Descriptor(
  name='OndemandData',
  full_name='blueapi.api.OndemandData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.OndemandData.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandChart', full_name='blueapi.api.OndemandData.ondemandChart', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=251,
)


_ONDEMANDCHART = _descriptor.Descriptor(
  name='OndemandChart',
  full_name='blueapi.api.OndemandChart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.OndemandChart.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='blueapi.api.OndemandChart.service', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalizedUsage', full_name='blueapi.api.OndemandChart.normalizedUsage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandCost', full_name='blueapi.api.OndemandChart.ondemandCost', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='blueapi.api.OndemandChart.usage', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=361,
)

_OPTIONSDATA.fields_by_name['optionsChart'].message_type = _OPTIONSCHART
_ONDEMANDDATA.fields_by_name['ondemandChart'].message_type = _ONDEMANDCHART
DESCRIPTOR.message_types_by_name['OptionsData'] = _OPTIONSDATA
DESCRIPTOR.message_types_by_name['OptionsChart'] = _OPTIONSCHART
DESCRIPTOR.message_types_by_name['OndemandData'] = _ONDEMANDDATA
DESCRIPTOR.message_types_by_name['OndemandChart'] = _ONDEMANDCHART
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OptionsData = _reflection.GeneratedProtocolMessageType('OptionsData', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONSDATA,
  '__module__' : 'api.coverage_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OptionsData)
  })
_sym_db.RegisterMessage(OptionsData)

OptionsChart = _reflection.GeneratedProtocolMessageType('OptionsChart', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONSCHART,
  '__module__' : 'api.coverage_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OptionsChart)
  })
_sym_db.RegisterMessage(OptionsChart)

OndemandData = _reflection.GeneratedProtocolMessageType('OndemandData', (_message.Message,), {
  'DESCRIPTOR' : _ONDEMANDDATA,
  '__module__' : 'api.coverage_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OndemandData)
  })
_sym_db.RegisterMessage(OndemandData)

OndemandChart = _reflection.GeneratedProtocolMessageType('OndemandChart', (_message.Message,), {
  'DESCRIPTOR' : _ONDEMANDCHART,
  '__module__' : 'api.coverage_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OndemandChart)
  })
_sym_db.RegisterMessage(OndemandChart)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
