# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/ripple/reseller.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from alphausblue.api import user_pb2 as api_dot_user__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/ripple/reseller.proto',
  package='blueapi.api.ripple',
  syntax='proto3',
  serialized_options=b'\n cloud.alphaus.blueapi.api.rippleB\026ApiRippleResellerProtoZ-github.com/alphauslabs/blue-sdk-go/api/ripple',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x61pi/ripple/reseller.proto\x12\x12\x62lueapi.api.ripple\x1a\x0e\x61pi/user.proto\"\xdc\x02\n\x08Reseller\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0f\n\x07groupId\x18\x03 \x01(\t\x12\x11\n\tgroupName\x18\x04 \x01(\t\x12\x11\n\tgroupType\x18\x05 \x01(\t\x12+\n\x08waveMeta\x18\x06 \x01(\x0b\x32\x19.blueapi.api.FeatureFlags\x12+\n\x08\x61quaMeta\x18\x07 \x01(\x0b\x32\x19.blueapi.api.FeatureFlags\x12\x1a\n\x12passwordUpdateTime\x18\x08 \x01(\t\x12\x12\n\nupdateTime\x18\t \x01(\t\x12\x14\n\x0cuserAccessId\x18\n \x01(\t\x12\x0e\n\x06userId\x18\x0b \x01(\t\x12\x1c\n\x14waveAvailabilityDays\x18\x0c \x01(\x05\x12\x16\n\x0ewaveRegistered\x18\r \x01(\t\x12\x12\n\nwaveStatus\x18\x0e \x01(\tBi\n cloud.alphaus.blueapi.api.rippleB\x16\x41piRippleResellerProtoZ-github.com/alphauslabs/blue-sdk-go/api/rippleb\x06proto3'
  ,
  dependencies=[api_dot_user__pb2.DESCRIPTOR,])




_RESELLER = _descriptor.Descriptor(
  name='Reseller',
  full_name='blueapi.api.ripple.Reseller',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='blueapi.api.ripple.Reseller.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='blueapi.api.ripple.Reseller.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupId', full_name='blueapi.api.ripple.Reseller.groupId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupName', full_name='blueapi.api.ripple.Reseller.groupName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupType', full_name='blueapi.api.ripple.Reseller.groupType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveMeta', full_name='blueapi.api.ripple.Reseller.waveMeta', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aquaMeta', full_name='blueapi.api.ripple.Reseller.aquaMeta', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passwordUpdateTime', full_name='blueapi.api.ripple.Reseller.passwordUpdateTime', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateTime', full_name='blueapi.api.ripple.Reseller.updateTime', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userAccessId', full_name='blueapi.api.ripple.Reseller.userAccessId', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='blueapi.api.ripple.Reseller.userId', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveAvailabilityDays', full_name='blueapi.api.ripple.Reseller.waveAvailabilityDays', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveRegistered', full_name='blueapi.api.ripple.Reseller.waveRegistered', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waveStatus', full_name='blueapi.api.ripple.Reseller.waveStatus', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=414,
)

_RESELLER.fields_by_name['waveMeta'].message_type = api_dot_user__pb2._FEATUREFLAGS
_RESELLER.fields_by_name['aquaMeta'].message_type = api_dot_user__pb2._FEATUREFLAGS
DESCRIPTOR.message_types_by_name['Reseller'] = _RESELLER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Reseller = _reflection.GeneratedProtocolMessageType('Reseller', (_message.Message,), {
  'DESCRIPTOR' : _RESELLER,
  '__module__' : 'api.ripple.reseller_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.ripple.Reseller)
  })
_sym_db.RegisterMessage(Reseller)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
